( cd usr/lib ; rm -rf libglide3.so )
( cd usr/lib ; ln -sf libglide3.so.3 libglide3.so )
( cd usr/lib ; rm -rf libglide3.so.3 )
( cd usr/lib ; ln -sf libglide3.so.3.10.0 libglide3.so.3 )
( cd usr/lib ; rm -rf libglide3x.so )
( cd usr/lib ; ln -sf libglide3.so libglide3x.so )
( cd usr/lib ; rm -rf libglide3x.so.3 )
( cd usr/lib ; ln -sf libglide3x.so libglide3x.so.3 )
